.. documentation master file.

============
Master Title
============

.. wikisection:: wiki
   :title: Good Section Title

   _

.. wikisection:: wiki
   :title: Duplicate Section Title

   _

.. wikisection:: wiki
   :title: Duplicate Section Title

   _

.. wikipage:: wiki

.. toctree::

